@@ -7,8 +7,8 @@
   /**
    * @ngInject
    */
-  PreferencesController.$inject = ['$q', '$window', '$state', '$mdConstant', '$mdMedia', '$mdSidenav', '$mdDialog', '$mdToast', 'sgSettings', 'sgFocus', 'Dialog', 'User', 'Account', 'Preferences', 'Authentication'];
-  function PreferencesController($q, $window, $state, $mdConstant, $mdMedia, $mdSidenav, $mdDialog, $mdToast, sgSettings, focus, Dialog, User, Account, Preferences, Authentication) {
+  PreferencesController.$inject = ['$q', '$window', '$state', '$mdMedia', '$mdSidenav', '$mdDialog', '$mdToast', 'sgSettings', 'sgFocus', 'Dialog', 'User', 'Account', 'Preferences', 'Authentication'];
+  function PreferencesController($q, $window, $state, $mdMedia, $mdSidenav, $mdDialog, $mdToast, sgSettings, focus, Dialog, User, Account, Preferences, Authentication) {
     var vm = this, mailboxes = [], today = new Date().beginOfDay();
 
     this.$onInit = function() {
@@ -16,21 +16,22 @@
       this.passwords = { newPassword: null, newPasswordConfirmation: null, oldPassword: null };
       this.timeZonesList = $window.timeZonesList;
       this.timeZonesSearchText = '';
-      this.sieveVariablesCapability = ($window.sieveCapabilities.indexOf('variables') >= 0);
       this.addressesSearchText = '';
       this.mailLabelKeyRE = new RegExp(/^(?!^_\$)[^(){} %*\"\\\\]*?$/);
-      this.emailSeparatorKeys = [
-        $mdConstant.KEY_CODE.ENTER,
-        $mdConstant.KEY_CODE.TAB,
-        $mdConstant.KEY_CODE.COMMA,
-        $mdConstant.KEY_CODE.SEMICOLON
-      ];
+      this.emailSeparatorKeys = Preferences.defaults.emailSeparatorKeys;
+      if (Preferences.defaults.SOGoMailAutoMarkAsReadMode == 'delay')
+        this.mailAutoMarkAsReadDelay = Math.max(1, this.preferences.defaults.SOGoMailAutoMarkAsReadDelay);
+      else
+        this.mailAutoMarkAsReadDelay = 5;
 
       // Set alternate avatar in User service
       if (Preferences.defaults.SOGoAlternateAvatar)
         User.$alternateAvatar = Preferences.defaults.SOGoAlternateAvatar;
 
-      this.preferences.hasActiveExternalSieveScripts();
+      if (sgSettings.activeUser('path').mail) {
+        this.sieveVariablesCapability = ($window.sieveCapabilities.indexOf('variables') >= 0);
+        this.preferences.hasActiveExternalSieveScripts();
+      }
       this.updateVacationDates();
     };
 
@@ -54,6 +55,7 @@
           });
         });
     };
+    
 
     this.onDesktopNotificationsChange = function() {
       if (this.preferences.defaults.SOGoDesktopNotifications)
@@ -107,6 +109,10 @@
       form.$setDirty();
     };
 
+    this.onMailAutoMarkAsReadDelay = function() {
+      this.preferences.defaults.SOGoMailAutoMarkAsReadDelay = this.mailAutoMarkAsReadDelay;
+    };
+
     this.addMailAccount = function(ev, form) {
       var account, index;
 
@@ -558,21 +564,6 @@
       }
     };
 
-    this.validateVacationStartDate = function(date) {
-      var d = vm.preferences.defaults, r = true;
-      if (d &&
-          d.Vacation &&
-          d.Vacation.enabled) {
-        if (d.Vacation.startDateEnabled) {
-          r = (!d.Vacation.endDateEnabled ||
-               !d.Vacation.endDate ||
-               date.getTime() <= d.Vacation.endDate.getTime());
-        }
-      }
-
-      return r;
-    };
-
     this.validateVacationEndDate = function(date) {
       var d = vm.preferences.defaults, r = true;
       if (d &&
@@ -587,6 +578,32 @@
 
       return r;
     };
+
+    this.toggleVacationStartTime = function() {
+      var v;
+
+      v = this.preferences.defaults.Vacation;
+
+      if (v.startTimeEnabled) {
+        // Enabling the start date
+        if (!v.startTime) {
+          v.startTime = new Date();
+        }
+      }
+    };
+
+    this.toggleVacationEndTime = function() {
+      var v;
+
+      v = this.preferences.defaults.Vacation;
+
+      if (v.endTimeEnabled) {
+        // Enabling the end date
+        if (!v.endTime) {
+          v.endTime = new Date();
+        }
+      }
+    };
   }
 
   angular
